@@ -1,9 +1,12 @@
 package Data::Tubes::Plugin::Util;
+
+# vim: ts=3 sts=3 sw=3 et ai :
+
 use strict;
 use warnings;
 use English qw< -no_match_vars >;
 use Data::Dumper;
-our $VERSION = '0.725001';
+our $VERSION = '0.725002';
 
 use Template::Perlish;
 use Log::Log4perl::Tiny qw< :easy :dead_if_first get_logger >;
@@ -98,15 +101,25 @@ sub log_helper {
 } ## end sub log_helper
 
 sub read_file {
+   my %preargs;
+   $preargs{filename} = shift(@_)
+     if (scalar(@_) % 2) && (ref($_[0]) ne 'HASH');
    my %args = normalize_args(
       @_,
       {
+         %preargs,
          binmode => ':encoding(UTF-8)',
       }
    );
+   defined $args{filename}
+     or LOGDIE 'read_file(): undefined filename';
    open my $fh, '<', $args{filename}
-     or LOGDIE "open('$args{filename}'): $OS_ERROR";
-   binmode $fh, $args{binmode} if defined $args{binmode};
+     or LOGDIE "read_file(): open('$args{filename}'): $OS_ERROR";
+   if (defined $args{binmode}) {
+      binmode $fh, $args{binmode}
+        or LOGDIE "read_file(): binmode()".
+         " for $args{filename} failed: $OS_ERROR";
+   }
    local $INPUT_RECORD_SEPARATOR;
    return <$fh>;
 } ## end sub read_file
